Diff
Modified: trunk/Source/WebCore/ChangeLog (209837 => 209838)
--- trunk/Source/WebCore/ChangeLog 2016-12-14 23:01:17 UTC (rev 209837)
+++ trunk/Source/WebCore/ChangeLog 2016-12-14 23:15:24 UTC (rev 209838)
@@ -1,5 +1,50 @@
2016-12-14 Dave Hyatt <[email protected]>
+ [CSS Parser] Rename StyleKeyframe to StyleRuleKeyframe
+ https://bugs.webkit.org/show_bug.cgi?id=165876
+
+ Reviewed by Simon Fraser.
+
+ * css/CSSKeyframeRule.cpp:
+ (WebCore::StyleRuleKeyframe::StyleRuleKeyframe):
+ (WebCore::StyleRuleKeyframe::~StyleRuleKeyframe):
+ (WebCore::StyleRuleKeyframe::mutableProperties):
+ (WebCore::StyleRuleKeyframe::keyText):
+ (WebCore::StyleRuleKeyframe::setKeyText):
+ (WebCore::StyleRuleKeyframe::cssText):
+ (WebCore::CSSKeyframeRule::CSSKeyframeRule):
+ (WebCore::StyleKeyframe::StyleKeyframe): Deleted.
+ (WebCore::StyleKeyframe::~StyleKeyframe): Deleted.
+ (WebCore::StyleKeyframe::mutableProperties): Deleted.
+ (WebCore::StyleKeyframe::keyText): Deleted.
+ (WebCore::StyleKeyframe::setKeyText): Deleted.
+ (WebCore::StyleKeyframe::cssText): Deleted.
+ * css/CSSKeyframeRule.h:
+ * css/CSSKeyframesRule.cpp:
+ (WebCore::StyleRuleKeyframes::keyframes):
+ (WebCore::StyleRuleKeyframes::parserAppendKeyframe):
+ (WebCore::StyleRuleKeyframes::wrapperAppendKeyframe):
+ (WebCore::CSSKeyframesRule::appendRule):
+ (WebCore::CSSKeyframesRule::item):
+ * css/CSSKeyframesRule.h:
+ * css/StyleResolver.cpp:
+ (WebCore::StyleResolver::styleForKeyframe):
+ (WebCore::StyleResolver::keyframeStylesForAnimation):
+ * css/StyleResolver.h:
+ * css/StyleRule.cpp:
+ (WebCore::StyleRuleBase::destroy):
+ * css/StyleRule.h:
+ * css/parser/CSSParser.cpp:
+ (WebCore::CSSParser::parseKeyframeRule):
+ * css/parser/CSSParser.h:
+ * css/parser/CSSParserImpl.cpp:
+ (WebCore::CSSParserImpl::parseDeferredKeyframeList):
+ (WebCore::CSSParserImpl::consumeKeyframesRule):
+ (WebCore::CSSParserImpl::consumeKeyframeStyleRule):
+ * css/parser/CSSParserImpl.h:
+
+2016-12-14 Dave Hyatt <[email protected]>
+
[CSS Parser] Make deferred parsing retain the sheet text. Fix invalidation to avoid deferred parsing.
https://bugs.webkit.org/show_bug.cgi?id=165868
Modified: trunk/Source/WebCore/css/CSSKeyframeRule.cpp (209837 => 209838)
--- trunk/Source/WebCore/css/CSSKeyframeRule.cpp 2016-12-14 23:01:17 UTC (rev 209837)
+++ trunk/Source/WebCore/css/CSSKeyframeRule.cpp 2016-12-14 23:15:24 UTC (rev 209838)
@@ -33,13 +33,13 @@
namespace WebCore {
-StyleKeyframe::StyleKeyframe(Ref<StyleProperties>&& properties)
+StyleRuleKeyframe::StyleRuleKeyframe(Ref<StyleProperties>&& properties)
: StyleRuleBase(Keyframe)
, m_properties(WTFMove(properties))
{
}
-StyleKeyframe::StyleKeyframe(std::unique_ptr<Vector<double>> keys, Ref<StyleProperties>&& properties)
+StyleRuleKeyframe::StyleRuleKeyframe(std::unique_ptr<Vector<double>> keys, Ref<StyleProperties>&& properties)
: StyleRuleBase(Keyframe)
, m_properties(WTFMove(properties))
, m_keys(*keys)
@@ -46,11 +46,11 @@
{
}
-StyleKeyframe::~StyleKeyframe()
+StyleRuleKeyframe::~StyleRuleKeyframe()
{
}
-MutableStyleProperties& StyleKeyframe::mutableProperties()
+MutableStyleProperties& StyleRuleKeyframe::mutableProperties()
{
if (!is<MutableStyleProperties>(m_properties.get()))
m_properties = m_properties->mutableCopy();
@@ -57,7 +57,7 @@
return downcast<MutableStyleProperties>(m_properties.get());
}
-String StyleKeyframe::keyText() const
+String StyleRuleKeyframe::keyText() const
{
StringBuilder keyText;
@@ -71,7 +71,7 @@
return keyText.toString();
}
-bool StyleKeyframe::setKeyText(const String& keyText)
+bool StyleRuleKeyframe::setKeyText(const String& keyText)
{
ASSERT(!keyText.isNull());
auto keys = CSSParser::parseKeyframeKeyList(keyText);
@@ -81,7 +81,7 @@
return true;
}
-String StyleKeyframe::cssText() const
+String StyleRuleKeyframe::cssText() const
{
StringBuilder result;
result.append(keyText());
@@ -94,7 +94,7 @@
return result.toString();
}
-CSSKeyframeRule::CSSKeyframeRule(StyleKeyframe& keyframe, CSSKeyframesRule* parent)
+CSSKeyframeRule::CSSKeyframeRule(StyleRuleKeyframe& keyframe, CSSKeyframesRule* parent)
: CSSRule(0)
, m_keyframe(keyframe)
{
Modified: trunk/Source/WebCore/css/CSSKeyframeRule.h (209837 => 209838)
--- trunk/Source/WebCore/css/CSSKeyframeRule.h 2016-12-14 23:01:17 UTC (rev 209837)
+++ trunk/Source/WebCore/css/CSSKeyframeRule.h 2016-12-14 23:15:24 UTC (rev 209838)
@@ -36,20 +36,18 @@
class StyleRuleCSSStyleDeclaration;
class CSSKeyframesRule;
-// FIXME-NEWPARSER: Rename this to StyleRuleKeyframe
-class StyleKeyframe final : public StyleRuleBase {
+class StyleRuleKeyframe final : public StyleRuleBase {
public:
- // FIXME-NEWPARSER: Remove this create function once we get rid of the old parser.
- static Ref<StyleKeyframe> create(Ref<StyleProperties>&& properties)
+ static Ref<StyleRuleKeyframe> create(Ref<StyleProperties>&& properties)
{
- return adoptRef(*new StyleKeyframe(WTFMove(properties)));
+ return adoptRef(*new StyleRuleKeyframe(WTFMove(properties)));
}
- static Ref<StyleKeyframe> create(std::unique_ptr<Vector<double>> keys, Ref<StyleProperties>&& properties)
+ static Ref<StyleRuleKeyframe> create(std::unique_ptr<Vector<double>> keys, Ref<StyleProperties>&& properties)
{
- return adoptRef(*new StyleKeyframe(WTFMove(keys), WTFMove(properties)));
+ return adoptRef(*new StyleRuleKeyframe(WTFMove(keys), WTFMove(properties)));
}
- ~StyleKeyframe();
+ ~StyleRuleKeyframe();
String keyText() const;
bool setKeyText(const String&);
@@ -68,8 +66,8 @@
String cssText() const;
private:
- explicit StyleKeyframe(Ref<StyleProperties>&&);
- StyleKeyframe(std::unique_ptr<Vector<double>>, Ref<StyleProperties>&&);
+ explicit StyleRuleKeyframe(Ref<StyleProperties>&&);
+ StyleRuleKeyframe(std::unique_ptr<Vector<double>>, Ref<StyleProperties>&&);
Ref<StyleProperties> m_properties;
Vector<double> m_keys;
@@ -88,11 +86,11 @@
CSSStyleDeclaration& style();
private:
- CSSKeyframeRule(StyleKeyframe&, CSSKeyframesRule* parent);
+ CSSKeyframeRule(StyleRuleKeyframe&, CSSKeyframesRule* parent);
CSSRule::Type type() const final { return KEYFRAME_RULE; }
- Ref<StyleKeyframe> m_keyframe;
+ Ref<StyleRuleKeyframe> m_keyframe;
mutable RefPtr<StyleRuleCSSStyleDeclaration> m_propertiesCSSOMWrapper;
friend class CSSKeyframesRule;
Modified: trunk/Source/WebCore/css/CSSKeyframesRule.cpp (209837 => 209838)
--- trunk/Source/WebCore/css/CSSKeyframesRule.cpp 2016-12-14 23:01:17 UTC (rev 209837)
+++ trunk/Source/WebCore/css/CSSKeyframesRule.cpp 2016-12-14 23:15:24 UTC (rev 209838)
@@ -74,13 +74,13 @@
m_deferredRules = nullptr;
}
-const Vector<Ref<StyleKeyframe>>& StyleRuleKeyframes::keyframes() const
+const Vector<Ref<StyleRuleKeyframe>>& StyleRuleKeyframes::keyframes() const
{
parseDeferredRulesIfNeeded();
return m_keyframes;
}
-void StyleRuleKeyframes::parserAppendKeyframe(RefPtr<StyleKeyframe>&& keyframe)
+void StyleRuleKeyframes::parserAppendKeyframe(RefPtr<StyleRuleKeyframe>&& keyframe)
{
if (!keyframe)
return;
@@ -87,7 +87,7 @@
m_keyframes.append(keyframe.releaseNonNull());
}
-void StyleRuleKeyframes::wrapperAppendKeyframe(Ref<StyleKeyframe>&& keyframe)
+void StyleRuleKeyframes::wrapperAppendKeyframe(Ref<StyleRuleKeyframe>&& keyframe)
{
parseDeferredRulesIfNeeded();
m_keyframes.append(WTFMove(keyframe));
@@ -142,7 +142,7 @@
ASSERT(m_childRuleCSSOMWrappers.size() == m_keyframesRule->keyframes().size());
CSSParser parser(parserContext());
- RefPtr<StyleKeyframe> keyframe = parser.parseKeyframeRule(ruleText);
+ RefPtr<StyleRuleKeyframe> keyframe = parser.parseKeyframeRule(ruleText);
if (!keyframe)
return;
@@ -215,7 +215,7 @@
ASSERT(m_childRuleCSSOMWrappers.size() == m_keyframesRule->keyframes().size());
RefPtr<CSSKeyframeRule>& rule = m_childRuleCSSOMWrappers[index];
if (!rule)
- rule = adoptRef(new CSSKeyframeRule(const_cast<StyleKeyframe&>(m_keyframesRule->keyframes()[index].get()), const_cast<CSSKeyframesRule*>(this)));
+ rule = adoptRef(new CSSKeyframeRule(const_cast<StyleRuleKeyframe&>(m_keyframesRule->keyframes()[index].get()), const_cast<CSSKeyframesRule*>(this)));
return rule.get();
}
Modified: trunk/Source/WebCore/css/CSSKeyframesRule.h (209837 => 209838)
--- trunk/Source/WebCore/css/CSSKeyframesRule.h 2016-12-14 23:01:17 UTC (rev 209837)
+++ trunk/Source/WebCore/css/CSSKeyframesRule.h 2016-12-14 23:15:24 UTC (rev 209838)
@@ -34,7 +34,7 @@
namespace WebCore {
class CSSRuleList;
-class StyleKeyframe;
+class StyleRuleKeyframe;
class CSSKeyframeRule;
class StyleRuleKeyframes final : public StyleRuleBase {
@@ -44,14 +44,14 @@
~StyleRuleKeyframes();
- const Vector<Ref<StyleKeyframe>>& keyframes() const;
- const Vector<Ref<StyleKeyframe>>* keyframesWithoutDeferredParsing() const
+ const Vector<Ref<StyleRuleKeyframe>>& keyframes() const;
+ const Vector<Ref<StyleRuleKeyframe>>* keyframesWithoutDeferredParsing() const
{
return !m_deferredRules ? &m_keyframes : nullptr;
}
- void parserAppendKeyframe(RefPtr<StyleKeyframe>&&);
- void wrapperAppendKeyframe(Ref<StyleKeyframe>&&);
+ void parserAppendKeyframe(RefPtr<StyleRuleKeyframe>&&);
+ void wrapperAppendKeyframe(Ref<StyleRuleKeyframe>&&);
void wrapperRemoveKeyframe(unsigned);
const AtomicString& name() const { return m_name; }
@@ -68,7 +68,7 @@
void parseDeferredRulesIfNeeded() const;
- mutable Vector<Ref<StyleKeyframe>> m_keyframes;
+ mutable Vector<Ref<StyleRuleKeyframe>> m_keyframes;
AtomicString m_name;
mutable std::unique_ptr<DeferredStyleGroupRuleList> m_deferredRules;
Modified: trunk/Source/WebCore/css/StyleResolver.cpp (209837 => 209838)
--- trunk/Source/WebCore/css/StyleResolver.cpp 2016-12-14 23:01:17 UTC (rev 209837)
+++ trunk/Source/WebCore/css/StyleResolver.cpp 2016-12-14 23:15:24 UTC (rev 209838)
@@ -444,7 +444,7 @@
return { state.takeStyle(), WTFMove(elementStyleRelations) };
}
-std::unique_ptr<RenderStyle> StyleResolver::styleForKeyframe(const RenderStyle* elementStyle, const StyleKeyframe* keyframe, KeyframeValue& keyframeValue)
+std::unique_ptr<RenderStyle> StyleResolver::styleForKeyframe(const RenderStyle* elementStyle, const StyleRuleKeyframe* keyframe, KeyframeValue& keyframeValue)
{
RELEASE_ASSERT(!m_isDeleted);
@@ -516,7 +516,7 @@
const StyleRuleKeyframes* keyframesRule = it->value.get();
auto* keyframes = &keyframesRule->keyframes();
- Vector<Ref<StyleKeyframe>> newKeyframesIfNecessary;
+ Vector<Ref<StyleRuleKeyframe>> newKeyframesIfNecessary;
bool hasDuplicateKeys = false;
HashSet<double> keyframeKeys;
@@ -535,7 +535,7 @@
// to copy the HashMap into a Vector.
if (hasDuplicateKeys) {
// Merge duplicate key times.
- HashMap<double, RefPtr<StyleKeyframe>> keyframesMap;
+ HashMap<double, RefPtr<StyleRuleKeyframe>> keyframesMap;
for (auto& originalKeyframe : keyframesRule->keyframes()) {
for (auto key : originalKeyframe->keys()) {
@@ -542,10 +542,10 @@
if (auto keyframe = keyframesMap.get(key))
keyframe->mutableProperties().mergeAndOverrideOnConflict(originalKeyframe->properties());
else {
- auto styleKeyframe = StyleKeyframe::create(MutableStyleProperties::create());
- styleKeyframe.ptr()->setKey(key);
- styleKeyframe.ptr()->mutableProperties().mergeAndOverrideOnConflict(originalKeyframe->properties());
- keyframesMap.set(key, styleKeyframe.ptr());
+ auto StyleRuleKeyframe = StyleRuleKeyframe::create(MutableStyleProperties::create());
+ StyleRuleKeyframe.ptr()->setKey(key);
+ StyleRuleKeyframe.ptr()->mutableProperties().mergeAndOverrideOnConflict(originalKeyframe->properties());
+ keyframesMap.set(key, StyleRuleKeyframe.ptr());
}
}
}
@@ -573,9 +573,9 @@
// If the 0% keyframe is missing, create it (but only if there is at least one other keyframe).
int initialListSize = list.size();
if (initialListSize > 0 && list[0].key()) {
- static StyleKeyframe* zeroPercentKeyframe;
+ static StyleRuleKeyframe* zeroPercentKeyframe;
if (!zeroPercentKeyframe) {
- zeroPercentKeyframe = &StyleKeyframe::create(MutableStyleProperties::create()).leakRef();
+ zeroPercentKeyframe = &StyleRuleKeyframe::create(MutableStyleProperties::create()).leakRef();
zeroPercentKeyframe->setKey(0);
}
KeyframeValue keyframeValue(0, nullptr);
@@ -585,9 +585,9 @@
// If the 100% keyframe is missing, create it (but only if there is at least one other keyframe).
if (initialListSize > 0 && (list[list.size() - 1].key() != 1)) {
- static StyleKeyframe* hundredPercentKeyframe;
+ static StyleRuleKeyframe* hundredPercentKeyframe;
if (!hundredPercentKeyframe) {
- hundredPercentKeyframe = &StyleKeyframe::create(MutableStyleProperties::create()).leakRef();
+ hundredPercentKeyframe = &StyleRuleKeyframe::create(MutableStyleProperties::create()).leakRef();
hundredPercentKeyframe->setKey(1);
}
KeyframeValue keyframeValue(1, nullptr);
Modified: trunk/Source/WebCore/css/StyleResolver.h (209837 => 209838)
--- trunk/Source/WebCore/css/StyleResolver.h 2016-12-14 23:01:17 UTC (rev 209837)
+++ trunk/Source/WebCore/css/StyleResolver.h 2016-12-14 23:15:24 UTC (rev 209838)
@@ -75,7 +75,7 @@
class StyleCachedImage;
class StyleGeneratedImage;
class StyleImage;
-class StyleKeyframe;
+class StyleRuleKeyframe;
class StyleProperties;
class StyleRule;
class StyleRuleKeyframes;
@@ -162,7 +162,7 @@
void setOverrideDocumentElementStyle(RenderStyle* style) { m_overrideDocumentElementStyle = style; }
private:
- std::unique_ptr<RenderStyle> styleForKeyframe(const RenderStyle*, const StyleKeyframe*, KeyframeValue&);
+ std::unique_ptr<RenderStyle> styleForKeyframe(const RenderStyle*, const StyleRuleKeyframe*, KeyframeValue&);
public:
// These methods will give back the set of rules that matched for a given element (or a pseudo-element).
Modified: trunk/Source/WebCore/css/StyleRule.cpp (209837 => 209838)
--- trunk/Source/WebCore/css/StyleRule.cpp 2016-12-14 23:01:17 UTC (rev 209837)
+++ trunk/Source/WebCore/css/StyleRule.cpp 2016-12-14 23:15:24 UTC (rev 209838)
@@ -95,7 +95,7 @@
delete downcast<StyleRuleNamespace>(this);
return;
case Keyframe:
- delete downcast<StyleKeyframe>(this);
+ delete downcast<StyleRuleKeyframe>(this);
return;
case Charset:
delete downcast<StyleRuleCharset>(this);
Modified: trunk/Source/WebCore/css/StyleRule.h (209837 => 209838)
--- trunk/Source/WebCore/css/parser/CSSParser.cpp 2016-12-14 23:01:17 UTC (rev 209837)
+++ trunk/Source/WebCore/css/parser/CSSParser.cpp 2016-12-14 23:15:24 UTC (rev 209838)
@@ -150,10 +150,10 @@
return CSSParserImpl::parseRule(string, context, sheet, CSSParserImpl::AllowImportRules);
}
-RefPtr<StyleKeyframe> CSSParser::parseKeyframeRule(const String& string)
+RefPtr<StyleRuleKeyframe> CSSParser::parseKeyframeRule(const String& string)
{
RefPtr<StyleRuleBase> keyframe = CSSParserImpl::parseRule(string, m_context, nullptr, CSSParserImpl::KeyframeRules);
- return downcast<StyleKeyframe>(keyframe.get());
+ return downcast<StyleRuleKeyframe>(keyframe.get());
}
bool CSSParser::parseSupportsCondition(const String& condition)
Modified: trunk/Source/WebCore/css/parser/CSSParser.h (209837 => 209838)
--- trunk/Source/WebCore/css/parser/CSSParser.h 2016-12-14 23:01:17 UTC (rev 209837)
+++ trunk/Source/WebCore/css/parser/CSSParser.h 2016-12-14 23:15:24 UTC (rev 209838)
@@ -36,7 +36,7 @@
class ImmutableStyleProperties;
class MutableStyleProperties;
class StyleRuleBase;
-class StyleKeyframe;
+class StyleRuleKeyframe;
class StyleSheetContents;
class CSSParser {
@@ -55,7 +55,7 @@
static RefPtr<StyleRuleBase> parseRule(const CSSParserContext&, StyleSheetContents*, const String&);
- RefPtr<StyleKeyframe> parseKeyframeRule(const String&);
+ RefPtr<StyleRuleKeyframe> parseKeyframeRule(const String&);
static std::unique_ptr<Vector<double>> parseKeyframeKeyList(const String&);
bool parseSupportsCondition(const String&);
Modified: trunk/Source/WebCore/css/parser/CSSParserImpl.cpp (209837 => 209838)
--- trunk/Source/WebCore/css/parser/CSSParserImpl.cpp 2016-12-14 23:01:17 UTC (rev 209837)
+++ trunk/Source/WebCore/css/parser/CSSParserImpl.cpp 2016-12-14 23:15:24 UTC (rev 209838)
@@ -191,7 +191,7 @@
return;
CSSParserImpl parser(deferredParser);
parser.consumeRuleList(tokenRange, KeyframesRuleList, [&keyframeRule](const RefPtr<StyleRuleBase>& keyframe) {
- keyframeRule.parserAppendKeyframe(downcast<const StyleKeyframe>(keyframe.get()));
+ keyframeRule.parserAppendKeyframe(downcast<const StyleRuleKeyframe>(keyframe.get()));
});
}
@@ -649,7 +649,7 @@
RefPtr<StyleRuleKeyframes> keyframeRule = StyleRuleKeyframes::create(name);
consumeRuleList(block, KeyframesRuleList, [keyframeRule](const RefPtr<StyleRuleBase>& keyframe) {
- keyframeRule->parserAppendKeyframe(downcast<const StyleKeyframe>(keyframe.get()));
+ keyframeRule->parserAppendKeyframe(downcast<const StyleRuleKeyframe>(keyframe.get()));
});
// FIXME-NEWPARSER: Find out why this is done. Behavior difference when prefixed?
@@ -714,7 +714,7 @@
}
*/
-RefPtr<StyleKeyframe> CSSParserImpl::consumeKeyframeStyleRule(CSSParserTokenRange prelude, CSSParserTokenRange block)
+RefPtr<StyleRuleKeyframe> CSSParserImpl::consumeKeyframeStyleRule(CSSParserTokenRange prelude, CSSParserTokenRange block)
{
std::unique_ptr<Vector<double>> keyList = consumeKeyframeKeyList(prelude);
if (!keyList)
@@ -726,7 +726,7 @@
}
consumeDeclarationList(block, StyleRule::Keyframe);
- return StyleKeyframe::create(WTFMove(keyList), createStyleProperties(m_parsedProperties, m_context.mode));
+ return StyleRuleKeyframe::create(WTFMove(keyList), createStyleProperties(m_parsedProperties, m_context.mode));
}
static void observeSelectors(CSSParserObserverWrapper& wrapper, CSSParserTokenRange selectors)
Modified: trunk/Source/WebCore/css/parser/CSSParserImpl.h (209837 => 209838)
--- trunk/Source/WebCore/css/parser/CSSParserImpl.h 2016-12-14 23:01:17 UTC (rev 209837)
+++ trunk/Source/WebCore/css/parser/CSSParserImpl.h 2016-12-14 23:15:24 UTC (rev 209838)
@@ -48,7 +48,7 @@
class CSSParserObserverWrapper;
class CSSSelectorList;
class CSSTokenizer;
-class StyleKeyframe;
+class StyleRuleKeyframe;
class StyleRule;
class StyleRuleBase;
class StyleRuleCharset;
@@ -142,7 +142,7 @@
// FIXME-NEWPARSER: Support "apply"
// void consumeApplyRule(CSSParserTokenRange prelude);
- RefPtr<StyleKeyframe> consumeKeyframeStyleRule(CSSParserTokenRange prelude, CSSParserTokenRange block);
+ RefPtr<StyleRuleKeyframe> consumeKeyframeStyleRule(CSSParserTokenRange prelude, CSSParserTokenRange block);
RefPtr<StyleRule> consumeStyleRule(CSSParserTokenRange prelude, CSSParserTokenRange block);
void consumeDeclarationList(CSSParserTokenRange, StyleRule::Type);
--- trunk/Source/WebCore/css/StyleRule.h 2016-12-14 23:01:17 UTC (rev 209837)
+++ trunk/Source/WebCore/css/StyleRule.h 2016-12-14 23:15:24 UTC (rev 209838)
@@ -33,7 +33,7 @@
class CSSStyleSheet;
class MediaQuerySet;
class MutableStyleProperties;
-class StyleKeyframe;
+class StyleRuleKeyframe;
class StyleProperties;
class StyleRuleKeyframes;
@@ -49,7 +49,7 @@
FontFace,
Page,
Keyframes,
- Keyframe, // Not used. These are internally non-rule StyleKeyframe objects.
+ Keyframe, // Not used. These are internally non-rule StyleRuleKeyframe objects.
Namespace,
Supports = 12,
#if ENABLE(CSS_DEVICE_ADAPTATION)
@@ -393,7 +393,7 @@
static bool isType(const WebCore::StyleRuleBase& rule) { return rule.isNamespaceRule(); }
SPECIALIZE_TYPE_TRAITS_END()
-SPECIALIZE_TYPE_TRAITS_BEGIN(WebCore::StyleKeyframe)
+SPECIALIZE_TYPE_TRAITS_BEGIN(WebCore::StyleRuleKeyframe)
static bool isType(const WebCore::StyleRuleBase& rule) { return rule.isKeyframeRule(); }
SPECIALIZE_TYPE_TRAITS_END()
Modified: trunk/Source/WebCore/css/parser/CSSParser.cpp (209837 => 209838)